@@ -4,7 +4,7 @@
 ##
 ##    class "fv" of function value objects
 ##
-##    $Revision: 1.182 $   $Date: 2023/11/04 04:53:51 $
+##    $Revision: 1.186 $   $Date: 2025/01/27 08:26:00 $
 ##
 ##
 ##    An "fv" object represents one or more related functions
@@ -399,11 +399,14 @@ flatfname <- function(x) {
   as.name(fn)
 }
 
-makefvlabel <- function(op=NULL, accent=NULL, fname, sub=NULL, argname="r") {
+makefvlabel <- function(op=NULL, accent=NULL, fname, sub=NULL, argname="r",
+                        pre=NULL, post=NULL) {
   ## de facto standardised label
   a <- "%s"
   if(!is.null(accent)) 
     a <- paste0(accent, paren(a))     ## eg hat(%s)
+  if(!is.null(pre)) # expression including '.'
+    a <- sub(".", a, as.character(pre), fixed=TRUE) # eg asin(sqrt(hat(%s)))
   if(!is.null(op))
     a <- paste0("bold", paren(op), "~", a)  ## eg bold(var)~hat(%s)
   if(is.null(sub)) {
@@ -420,6 +423,8 @@ makefvlabel <- function(op=NULL, accent=NULL, fname, sub=NULL, argname="r") {
     }
   } 
   a <- paste0(a, paren(argname))
+  if(!is.null(post)) # expression including '.'
+    a <- sub(".", a, as.character(post), fixed=TRUE) 
   return(a)
 }
 
@@ -537,6 +542,11 @@ bind.fv <- function(x, y, labl=NULL, desc=NULL, preferred=NULL, clip=FALSE) {
     if(is.null(desc)) desc <- attr(y, "desc")[-yrpos]
     ##
     y <- ystrip
+  } else if(is.function(y)) {
+    ## evaluate the function 'y' at the argument values of the first object
+    xvals <- x[[fvnames(x, ".x")]]
+    yvals <- y(xvals)
+    y <- data.frame(y=yvals)
   } else {
     ## y is a matrix or data frame
     y <- as.data.frame(y)
@@ -590,14 +600,40 @@ cbind.fv <- function(...) {
     ## could be an fv object 
     if(is.fv(a))
       return(a)
+    ## a is a list of arguments
     n <- length(a)
   }
+  ## First argument is template
   z <- a[[1L]]
   if(!is.fv(z))
     stop("First argument should be an object of class fv")
-  if(n > 1)
-    for(i in 2:n) 
-      z <- bind.fv(z, a[[i]])
+  ## Subsequent arguments
+  if(n > 1) {
+    ## save dotnames (only those explicitly given in data -- no 'guessing')
+    dn <- fvnames(z, ".")
+    if(any(isfun <- sapply(a, is.function))) {
+      ## Function(s) will be applied to 'r' values
+      xvals <- z[[fvnames(z, ".x")]]
+      ## Determine variable names using names in cbind call, or default
+      nama <- good.names(names(a), "V", 1:n)
+    }
+    for(i in 2:n) {
+      ai <- a[[i]]
+      if(isfun[i]) {
+        ## apply function to 'r' values
+        yvals <- ai(xvals)
+        ## convert to data frame 
+        ai <- data.frame(y=yvals)
+        colnames(ai) <- nama[i]
+      } else if(is.fv(ai)) {
+        ## collect more dotnames
+        dn <- c(dn, fvnames(ai, "."))
+      }
+      z <- bind.fv(z, ai)
+    }
+    ## reattach dotnames
+    fvnames(z, ".") <- dn
+  }
   return(z)
 }
 
